@@ -1,6 +1,6 @@
 package Mason::Request;
 BEGIN {
-  $Mason::Request::VERSION = '2.12';
+  $Mason::Request::VERSION = '2.13';
 }
 use Carp;
 use File::Basename;
@@ -141,6 +141,7 @@ method filter () {
 
 method flush_buffer () {
     my $request_buffer = $self->_request_buffer;
+    $self->process_output($request_buffer);
     $self->out_method->( $$request_buffer, $self )
       if length $$request_buffer;
     $$request_buffer = '';
@@ -243,6 +244,10 @@ method match_request_path ($request_path) {
     $self->interp->match_request_path->( $self, $request_path );
 }
 
+method process_output ($outref) {
+                                            # No-op by default
+}
+
 method run () {
 
     # Get path and either hash or hashref of arguments
@@ -775,11 +780,17 @@ Given a top level I<$request_path>, return a corresponding component path or
 undef if none was found. Search includes dhandlers and index files. See
 L<Mason::Manual::RequestDispatch>.
 
+=item process_output ($outref)
+
+This method is called on the output buffer right before it is sent to its final
+destination. I<$outref> is a reference to the output string; the method can
+modify it as desired.
+
 =for html <a name="run" />
 
-=item run (request_path, args)
+=item run ($request_path, args)
 
-Runs the request with I<request_path> and I<args>, where the latter can be
+Runs the request with I<$request_path> and I<args>, where the latter can be
 either a hashref or a hash. This is generally called via << $interp->run >>.
 
 =for html <a name="with_tied_print" />
